
dialogId("del-v-dve", "font_big", "See? This ship had two gun decks. It must have been a man-of-war. The acrid smell of gunpowder still seems to linger in the air...")

dialogId("del-m-voda", "font_small", "You mean, in the water.")

dialogId("del-m-ci", "font_small", "Whose ship was she? Maybe she served under admiral Nelson... or captain Hornblower.")

dialogId("del-v-splet", "font_big", "No, I think you’re about a hundred years off.")

dialogId("del-v-mec", "font_big", "I have a feeling we’re going to need that sword.")

dialogId("del-m-tus", "font_small", "You and your ‘feelings’. Besides, we’re not supposed to be giving any hints.")

dialogId("del-m-jedn0", "font_small", "That was a little too simple, wasn’t it?")

dialogId("del-m-jedn1", "font_small", "Could it possibly be so simple?")

dialogId("del-m-jedn2", "font_small", "There must be some kind of mistake.")
